@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
-TRPROGRAM=$(printf $1 | tr - _)
+TRPROGNAME=$(printf $1 | tr - _)
 cat > $1/src/Makefile.am <<EOF
 bin_PROGRAMS = $1
-${TRPROGRAM}_SOURCES = main.c
+${TRPROGNAME}_SOURCES = main.c
 EOF
